/***********************************************************************************************************************************
Parse Configuration
***********************************************************************************************************************************/
#ifndef CONFIG_PARSE_H
#define CONFIG_PARSE_H

#include "config/config.h"

/***********************************************************************************************************************************
Functions
***********************************************************************************************************************************/
void configParse(unsigned int argListSize, const char *argList[], bool resetLogLevel);

#endif
